@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::App::Action;
-$Footprintless::App::Action::VERSION = '1.14';
+$Footprintless::App::Action::VERSION = '1.15';
 # ABSTRACT: A base class for actions
 # PODNAME: Footprintless::App::Action
 
@@ -27,10 +27,15 @@ sub abstract {
 
 sub description {
     my ($self_or_class) = @_;
-    my $description = ucfirst( $self_or_class->abstract() );
+
+    require Footprintless::App::DocumentationUtil;
+    my $description = Footprintless::App::DocumentationUtil::description($self_or_class)
+        || ucfirst( $self_or_class->abstract() );
+
     if ( scalar( $self_or_class->opt_spec() ) ) {
         $description .= "\n\nAvailable options:\n";
     }
+
     return $description;
 }
 
@@ -81,7 +86,7 @@ Footprintless::App::Action - A base class for actions
 
 =head1 VERSION
 
-version 1.14
+version 1.15
 
 =head1 FUNCTIONS
 
