@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::App::DocumentationUtil;
-$Footprintless::App::DocumentationUtil::VERSION = '1.14';
+$Footprintless::App::DocumentationUtil::VERSION = '1.15';
 # ABSTRACT: A utility class for generating help documentation from POD
 # PODNAME: Footprintless::App::DocumentationUtil
 
@@ -15,6 +15,8 @@ my $logger = Log::Any->get_logger();
 our @EXPORT_OK = qw(
     abstract
     description
+    examples
+    pod_section
 );
 
 sub abstract {
@@ -28,13 +30,21 @@ sub abstract {
 }
 
 sub description {
-    my ($self_or_class) = @_;
+    return pod_section( $_[0], 'DESCRIPTION', 0, qr/Description:\n/ );
+}
+
+sub examples {
+    return pod_section( $_[0], 'EXAMPLES' );
+}
+
+sub pod_section {
+    my ( $self_or_class, $section, $indent, $remove ) = @_;
 
     my $pm_file = _pm_file($self_or_class)
         || return $self_or_class->abstract();
 
-    my $description = '';
-    open( my $output, '>', \$description );
+    my $pod = '';
+    open( my $output, '>', \$pod );
 
     require Pod::Usage;
     Pod::Usage::pod2usage(
@@ -42,14 +52,16 @@ sub description {
         -output   => $output,
         -exit     => "NOEXIT",
         -verbose  => 99,
-        -sections => "DESCRIPTION",
-        indent    => 0
+        -sections => $section,
+        indent    => $indent
     );
 
-    $description =~ s/Description:\n//m;
-    chomp($description);
+    if ($pod) {
+        $pod =~ s/$remove//m if ($remove);
+        chomp($pod);
+    }
 
-    return $description;
+    return $pod;
 }
 
 sub _pm_file {
@@ -86,7 +98,7 @@ Footprintless::App::DocumentationUtil - A utility class for generating help docu
 
 =head1 VERSION
 
-version 1.14
+version 1.15
 
 =head1 EXPORT_OK
 
@@ -100,6 +112,17 @@ C<$self_or_class>.
 Returns the content of the C<DESCRIPTION> section of the pod for 
 C<$self_or_class>.
 
+=head2 examples($self_or_class)
+
+Returns the content of the C<EXAMPLES> section of the pod for 
+C<$self_or_class>.
+
+=head2 pod_section($self_or_class, $section, $indent, $remove)
+
+Returns the content of the C<$section> section of the pod for 
+C<$self_or_class> with indent level C<$indent>.  If specified, 
+C<$remove> a regex used to find content to remove.
+
 =head1 AUTHOR
 
 Lucas Theisen <lucastheisen@pastdev.com>
